summaryrefslogtreecommitdiffstats
path: root/chrome/browser/cocoa/fullscreen_window.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/cocoa/fullscreen_window.h')
-rw-r--r--chrome/browser/cocoa/fullscreen_window.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/chrome/browser/cocoa/fullscreen_window.h b/chrome/browser/cocoa/fullscreen_window.h
index d43059d..ba01abf 100644
--- a/chrome/browser/cocoa/fullscreen_window.h
+++ b/chrome/browser/cocoa/fullscreen_window.h
@@ -3,14 +3,14 @@
// found in the LICENSE file.
#include <Cocoa/Cocoa.h>
-#import "chrome/browser/cocoa/chrome_event_processing_window.h"
+#import "chrome/browser/cocoa/chrome_browser_window.h"
-// A FullscreenWindow is a borderless window suitable for going
-// fullscreen. The returned window is NOT release when closed and is
-// not initially visible.
-// FullscreenWindow derives from ChromeEventProcessingWindow to inherit
-// special event handling (e.g. handleExtraKeyboardShortcut).
-@interface FullscreenWindow : ChromeEventProcessingWindow
+// A FullscreenWindow is a borderless window suitable for going fullscreen. The
+// returned window is NOT release when closed and is not initially visible.
+// FullscreenWindow derives from ChromeBrowserWindow to inherit hole punching,
+// theming methods, and special event handling
+// (e.g. handleExtraKeyboardShortcut).
+@interface FullscreenWindow : ChromeBrowserWindow
// Initialize a FullscreenWindow for the given screen.
// Designated initializer.